*[FPR]: False Positive Rate - the probability of incorrectly reporting an item as present
*[HLL]: HyperLogLog - a probabilistic cardinality estimator
*[CMS]: Count-Min Sketch - a probabilistic frequency estimator
*[LSH]: Locality-Sensitive Hashing - a technique for approximate nearest neighbor search
*[PyO3]: Python bindings for Rust
*[API]: Application Programming Interface
